from typing import List
from pathlib import Path
from logging import getLogger
from tempfile import TemporaryFile
import tarfile

from .util import create_temporary_docker_container, add_text_file_to_tarfile


LOGGER = getLogger(__name__)


def copy_input_to(client, volume, input_images: List[Path]) -> None:
    LOGGER.info(f'Copying {len(input_images)} input images to Docker volume {volume.short_id}')
    volumes = {volume.name: {'bind': '/input', 'mode': 'rw'}}
    with create_temporary_docker_container(client, 'ahisto/empty', command='cmd',
                                           volumes=volumes) as container:
        with TemporaryFile('w+b') as tf:
            with tarfile.open(fileobj=tf, mode='w') as tar:
                filenames = []
                for input_image_number, input_image in enumerate(input_images):
                    filename = f'/input/{input_image_number}{input_image.suffix}'
                    filenames.append(filename)
                    tar.add(str(input_image.resolve()), filename)
                add_text_file_to_tarfile('list.txt', '\n'.join(filenames), tar)
            tf.seek(0)
            container.put_archive(path='/input', data=tf)


def copy_output_from(client, output_volume, input_images: List[Path], output_dir: Path) -> None:
    pass
